from illuminate.interface import IFinding


class Finding(IFinding):
    """
    Finding class, contains data that will be passed to Adapter object's
    adapt method.
    """
